@@ -71,7 +71,7 @@ def main():
         case 'view':
             mode_view.run_mode()
         case 'simulate':
-            mode_simulate.run_mode(goal=int(args.goal))
+            mode_simulate.run_mode(goal=int(args.goal), lattice=parse_lattice(args.lattice))
         case 'interactive':
             mode_interactive.run_mode(goal=int(args.goal), dimension=int(args.dimension),
                                       lattice=parse_lattice(args.lattice), windows_mode=args.windows)
