@@ -1,3 +1,5 @@
+import random
+
 import open3d as o3d
 
 from .additive_simulation import SimpleNeighborhood, OmniSimulation
@@ -14,22 +16,14 @@ def plot_sim(sim):
     o3d.visualization.draw_geometries([points])
 
 
-def run_mode(goal):
-    simulation = OmniSimulation(SimpleNeighborhood(fcc_transform()), None, [0] * (3 if is_2d else 4))
+def run_mode(goal, lattice):
+    simulation = OmniSimulation(SimpleNeighborhood(lattice), None, (0, 0, 0, 0))
+    input("Press enter to continue...")
 
     p = ProgressBar(goal, lambda: simulation.energy)
 
     for i in range(goal):
         p(i)
+        simulation.add_atom(lambda l: random.randrange(l))
 
-# def large_sim():
-#     simulation = OmniSimulation(SimpleNeighborhood(fcc_transform()), None, (0, 0, 0, 0))
-#     goal = 1_000
-#
-#     p = ProgressBar(goal, lambda: simulation.energy)
-#
-#     for i in range(goal):
-#         p(i)
-#         simulation.add_atom(lambda l: random.randrange(l))
-#
-#     plot_sim(simulation)
+    plot_sim(simulation)
\ No newline at end of file
